@@ -30,7 +30,7 @@ worker_processes 3
 
 # Help ensure your application will always spawn in the symlinked
 # "current" directory that Capistrano sets up.
-working_directory ENV['gitlab_home'] # available in 0.94.0+
+working_directory ENV['gitlab_app_root'] # available in 0.94.0+
 
 # Listen on both a Unix domain socket and a TCP port.
 # If you are load-balancing multiple Unicorn masters, lower the backlog
