@@ -1,9 +1,9 @@
 ucount=$(ls -1 | wc -l)
 dcount=$(cat debian/install |cut -d' ' -f1|grep -v debian |wc -l)
-ignored=5
+ignored=7
 if ! [ $(echo "$ucount" - "$dcount"|bc) -eq $ignored ]; then
   echo "Found new files added by upstream and not added to debian/install"
-  echo "Add them to debian/install or adjust 'ignored=5'"
+  echo "Add them to debian/install or adjust 'ignored=${ignored}'"
   echo "in debian/upstream-file-count-check.sh as required"
   exit 1
 fi
